@@ -1,3 +1,4 @@
+import sys
 from magicdb.Models import DateModel
 from datetime import datetime
 from typing import Any
@@ -156,33 +157,42 @@ async def make_request_obj_from_request(request: FastAPIRequest):
         port=request.url.port,
     )
 
-    aws_fields = ['aws_request_id', 'log_group_name', 'log_stream_name', 'function_name', 'memory_limit_in_mb']
+    aws_fields = [
+        "aws_request_id",
+        "log_group_name",
+        "log_stream_name",
+        "function_name",
+        "memory_limit_in_mb",
+    ]
 
-    if 'aws.context' in request.scope:
-        context = request.scope['aws.context']
+    if "aws.context" in request.scope:
+        context = request.scope["aws.context"]
         [setattr(request_obj, field, getattr(context, field)) for field in aws_fields]
 
-        cloudwatch_base_url = 'https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group='
-        request_obj.log_group_url = f'{cloudwatch_base_url}{request_obj.log_group_name}'
-        request_obj.stream_url = f'{request_obj.log_group_url};stream={request_obj.log_stream_name}'.replace(
-            '[$LATEST]', '%5B$LATEST%5D')
+        cloudwatch_base_url = "https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group="
+        request_obj.log_group_url = f"{cloudwatch_base_url}{request_obj.log_group_name}"
+        request_obj.stream_url = f"{request_obj.log_group_url};stream={request_obj.log_stream_name}".replace(
+            "[$LATEST]", "%5B$LATEST%5D"
+        ).replace(
+            "logStream", "logEventViewer"
+        )
 
-    if 'aws.event' in request.scope:
-        event = request.scope['aws.event']
-        request_context = event.get('requestContext')
+    if "aws.event" in request.scope:
+        event = request.scope["aws.event"]
+        request_context = event.get("requestContext")
         if request_context:
-            request_obj.request_id = request_context.get('requestId')
-            request_obj.domain_name = request_context.get('domainName')
-            request_obj.api_id = request_context.get('apiId')
+            request_obj.request_id = request_context.get("requestId")
+            request_obj.domain_name = request_context.get("domainName")
+            request_obj.api_id = request_context.get("apiId")
 
     return request_obj
 
 
 async def make_call_from_request_and_response(
-        request: FastAPIRequest,
-        response: Optional[FastApiResponse],
-        error: Optional[Exception],
-        times_dict: dict,
+    request: FastAPIRequest,
+    response: Optional[FastApiResponse],
+    error: Optional[Exception],
+    times_dict: dict,
 ):
     if not g.settings.save_calls:
         return
@@ -218,4 +228,9 @@ async def make_call_from_request_and_response(
         times=Times(**times_dict),
     )
 
+    print("call size", sys.getsizeof(call))
+    print("response_obj size", sys.getsizeof(response_obj))
+    print("request_obj size", sys.getsizeof(request_obj))
+    print("error_obj size", sys.getsizeof(error_obj))
+
     save_call(call)
